Sweep

Struct Sweep 

pub struct Sweep<L>(pub L);
Apply a local trial move to every body in the microstate.

The first field in the tuple struct determines what trial moves Sweep attempts.

Example

use hoomd_mc::{Sweep, Translate};
use hoomd_vector::Cartesian;

let d = 0.1;
let translate =
    Translate::<Cartesian<2>>::with_maximum_distance(d.try_into()?);
let translate_sweep = Sweep(translate);

Tuple Fields

0: L